@@ -36,9 +36,19 @@ arrange..tidytable <- function(.df, ...) {
 
   dots <- prep_exprs(dots, .df, dt_env = dt_env)
 
-  i <- expr(order(!!!dots))
+  is_expr <- map_lgl.(dots, ~ !is_symbol(.x) && !is_call(.x, "-", 1))
 
-  dt_expr <- call2_i(.df, i)
+  if (any(is_expr)) {
+    i <- expr(order(!!!dots))
+
+    dt_expr <- call2_i(.df, i)
+  } else {
+    .df <- copy(.df)
+
+    dt_expr <- call2("setorder", quo(.df), !!!dots, .ns = "data.table")
+
+    dt_expr <- call2("[", dt_expr)
+  }
 
   eval_tidy(dt_expr)
 }
