@@ -1,10 +1,11 @@
 test_that("can do group aggregation with .by", {
-  df <- tidytable(x = 1:4, y = c("a","a","a","b"))
+  df <- tidytable(x = 4:1, y = c("b","a","a","a"))
 
   tidytable_df <- df %>%
     summarize.(avg_x = mean(x), .by = y)
 
-  datatable_df <- df[, list(avg_x = mean(x)), by = y]
+  datatable_df <- df[, list(avg_x = mean(x)), keyby = y]
+  setkey(datatable_df, NULL)
 
   expect_equal(tidytable_df, datatable_df)
 })
@@ -77,31 +78,20 @@ test_that("can do group aggregation with by c()", {
   expect_equal(tidytable_df, datatable_df)
 })
 
-test_that("can use .sort & doesn't modify-by-reference", {
+test_that("can use .sort", {
   test_df <- tidytable(x = 1:3, y = c("b", "a", "a"), z = c("b", "a", "a"))
 
   tidytable_df <- test_df %>%
     summarize.(avg_x = mean(x),
                .by = c(y, z),
-               .sort = TRUE)
+               .sort = FALSE)
 
-  datatable_df <- test_df[, list(avg_x = mean(x)), keyby = list(y, z)]
+  datatable_df <- test_df[, list(avg_x = mean(x)), by = list(y, z)]
 
   expect_equal(tidytable_df$avg_x, datatable_df$avg_x)
   expect_named(test_df, c("x", "y", "z"))
 })
 
-test_that("can do group aggregation with by enhanced selection", {
-  df <- tidytable(x = 1:4, y = c("a","a","a","b"))
-
-  tidytable_df <- df %>%
-    summarize.(avg_x = mean(x), .by = where(is.character))
-
-  datatable_df <- df[, list(avg_x = mean(x)), by = y]
-
-  expect_equal(tidytable_df, datatable_df)
-})
-
 test_that("can do group aggregation with by w/ data.frame", {
   df <- data.frame(x = 1:4, y = c("a","a","a","b"),
                    stringsAsFactors = FALSE)
